@@ -1,5 +1,5 @@
 __all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint',
-           'ProfileObjectPoint', 'UserProfileIpExistsPoint', 'SetCreditScorePoint', 'DocumentPoint',
+           'ProfileObjectPoint', 'UserProfileIpExistsPoint', 'UnlimitedSetCreditScorePoint', 'DocumentPoint',
            'SendSignPoint', 'ValidateSignPoint', 'AgreementPoint')
 
 from expressmoney.api import *
@@ -66,7 +66,6 @@ class ProfileReadContract(ProfileCreateContract):
     is_signed = serializers.BooleanField()
     credit_score = serializers.DecimalField(max_digits=3, decimal_places=2, allow_null=True)
     credit_score_created = serializers.DateTimeField(allow_null=True)
-    is_callback = serializers.BooleanField()
     # Address
     address_code = serializers.CharField(max_length=64, allow_blank=True)
     address_coordinates = serializers.CharField(max_length=64, allow_blank=True)
@@ -181,6 +180,12 @@ class SetCreditScoreID(ID):
     _view_set = 'set_credit_score'
 
 
+class UnlimitedSetCreditScoreID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'unlimited_set_credit_score'
+
+
 class LogID(ID):
     _service = SERVICE
     _app = 'profiles'
@@ -254,6 +259,11 @@ class SetCreditScorePoint(CreatePointMixin, ContractPoint):
     _create_contract = SetCreditScoreCreateContract
 
 
+class UnlimitedSetCreditScorePoint(CreatePointMixin, ContractPoint):
+    _point_id = UnlimitedSetCreditScoreID()
+    _create_contract = SetCreditScoreCreateContract
+
+
 class LogPoint(CreatePointMixin, ContractPoint):
     _point_id = LogID()
     _create_contract = LogCreateContract
